
# Slot: relation




URI: [biolink:gene_to_expression_site_association_relation](https://w3id.org/biolink/vocab/gene_to_expression_site_association_relation)

## Domain and Range

[GeneToExpressionSiteAssociation](GeneToExpressionSiteAssociation.md) ->  <sub>REQ</sub> [Uriorcurie](Uriorcurie.md)

## Parents

 *  is_a: [relation](relation.md)

## Children


## Used by

 * [GeneToExpressionSiteAssociation](GeneToExpressionSiteAssociation.md)
